@@ -1,5 +1,5 @@
 """
-Copyright (C) 2020 Murilo Marques Marinho (www.murilomarinho.info)
+Copyright (C) 2020-2022 Murilo Marques Marinho (www.murilomarinho.info)
 This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 version.
@@ -12,41 +12,47 @@ from umirobot.shared_memory.umirobot_shared_memory_common import shared_memory_m
 
 
 class UMIRobotSharedMemoryProvider:
-    def __init__(self, shared_memory_manager, lock, dofs=6, n_potentiometers=6):
+    def __init__(self, shared_memory_manager, lock, n_servos=6, n_potentiometers=6, n_digital_inputs=5):
         self.shared_memory_manager = shared_memory_manager
         self.lock = lock
-        self.dofs = dofs
+        self.n_servos = n_servos
         self.n_potentiometers = n_potentiometers
+        self.n_digital_inputs = n_digital_inputs
         self.connection_information_dict = shared_memory_map
         self.connection_information = shared_memory_manager.ShareableList(
-            [dofs,
+            [n_servos,
              n_potentiometers,
+             n_digital_inputs,
              False,
              "                                               ",
              False,
              False]
         )
         self.shareable_q = shared_memory_manager.ShareableList(
-            [None]*dofs
+            [None] * n_servos
         )
         self.shareable_qd = shared_memory_manager.ShareableList(
-            [None]*dofs
+            [None] * n_servos
         )
         self.shareable_potentiometer_values = shared_memory_manager.ShareableList(
-            [None]*n_potentiometers
+            [None] * n_potentiometers
+        )
+        self.shareable_digital_in_values = shared_memory_manager.ShareableList(
+            [None] * n_digital_inputs
         )
 
     def get_shared_memory_receiver_initializer_args(self):
         return (self.connection_information,
                 self.shareable_q,
                 self.shareable_qd,
-                self.shareable_potentiometer_values)
+                self.shareable_potentiometer_values,
+                self.shareable_digital_in_values)
 
     def send_q(self, q):
         if q is not None:
-            if len(q) == self.dofs:
+            if len(q) == self.n_servos:
                 self.lock.acquire()
-                for i in range(0, self.dofs):
+                for i in range(0, self.n_servos):
                     self.shareable_q[i] = q[i]
                 self.lock.release()
 
@@ -58,6 +64,14 @@ class UMIRobotSharedMemoryProvider:
                     self.shareable_potentiometer_values[i] = potentiometer_values[i]
                 self.lock.release()
 
+    def send_digital_in_values(self, digital_in_values):
+        if digital_in_values is not None:
+            if len(digital_in_values) == self.n_digital_inputs:
+                self.lock.acquire()
+                for i in range(0, self.n_digital_inputs):
+                    self.shareable_digital_in_values[i] = digital_in_values[i]
+                self.lock.release()
+
     def get_qd(self):
         self.lock.acquire()
         qd = list(self.shareable_qd)
